centos防火墙配置「建议收藏」

centos防火墙配置「建议收藏」centos防火墙配置1.centos中firewalld与iptablescentos7以前的版本默认使用iptables服务进行管理防火墙规则。centos7以及其以上版本默认使用firewalld服务管理防火墙。所以在centos8中,就使用其默认的firewalld配置防火墙。2.firewalld相关命令进程与状态相关systemctlstartfirewalld.service#启动防火墙systemctlstopfirewalld.servic

大家好,又见面了,我是你们的朋友全栈君。

centos防火墙配置

1.centos中firewalld与iptables

centos7以前的版本默认使用iptables服务进行管理防火墙规则。centos7以及其以上版本默认使用firewalld服务管理防火墙。所以在centos8中,就使用其默认的firewalld配置防火墙。

2.firewalld相关命令

  • 进程与状态相关

    systemctl start firewalld.service            #启动防火墙 
    systemctl stop firewalld.service             #停止防火墙 
    systemctl status firewalld                   #查看防火墙状态
    systemctl enable firewalld                   #设置防火墙随系统启动
    systemctl disable firewalld                  #禁止防火墙随系统启动
    firewall-cmd --state                         #查看防火墙状态 
    firewall-cmd --reload                        #更新防火墙规则 
    firewall-cmd --list-ports                    #查看所有打开的端口 
    firewall-cmd --list-services                 #查看所有允许的服务 
    firewall-cmd --get-services                  #获取所有支持的服务 
    
  • 区域相关

    firewall-cmd --list-all-zones                    #查看所有区域信息 
    firewall-cmd --get-active-zones                  #查看活动区域信息 
    firewall-cmd --set-default-zone=public           #设置public为默认区域 
    firewall-cmd --get-default-zone                  #查看默认区域信息 
    
  • 接口相关

    firewall-cmd --zone=public --add-interface=eth0          #将接口eth0加入区域public
    firewall-cmd --zone=public --remove-interface=eth0       #从区域public中删除接口eth0 
    firewall-cmd --zone=default --change-interface=eth0      #修改接口eth0所属区域为default 
    firewall-cmd --get-zone-of-interface=eth0                #查看接口eth0所属区域 
    
  • 端口控制

    firewall-cmd --query-port=8080/tcp                       # 查询端口是否开放
    firewall-cmd --add-port=8080/tcp --permanent             #永久添加8080端口例外(全局)
    firewall-cmd --remove-port=8800/tcp --permanent          #永久删除8080端口例外(全局)
    firewall-cmd --add-port=65001-65010/tcp --permanent      #永久增加65001-65010例外(全局) 
    firewall-cmd  --zone=public --add-port=8080/tcp --permanent            #永久添加8080端口例外(区域public)
    firewall-cmd  --zone=public --remove-port=8080/tcp --permanent         #永久删除8080端口例外(区域public)
    firewall-cmd  --zone=public --add-port=65001-65010/tcp --permanent     #永久增加65001-65010例外(区域public
    

3.常用命令

  • 最常用命令

    firewalld-cmd --zone=public --add-ports=8080/tcp --permanent #开启8080端口访问规则
    firewall-cmd --reload                        #更新防火墙规则,立即生效 
    
  • 命令解析

      firwall-cmd:是Linux提供的操作firewall的一个工具(服务)命令
      --zone #作用域
      --add-port=8080/tcp #添加端口,格式为:端口/通讯协议 ;add表示添加,remove则对应移除
      --permanent #永久生效,没有此参数重启后失效
    
版权声明:本文内容由互联网用户自发贡献,该文观点仅代表作者本人。本站仅提供信息存储空间服务,不拥有所有权,不承担相关法律责任。如发现本站有涉嫌侵权/违法违规的内容, 请发送邮件至 举报,一经查实,本站将立刻删除。

发布者:全栈程序员-站长,转载请注明出处:https://javaforall.net/148796.html原文链接:https://javaforall.net

赞 (0)
全栈程序员-站长的头像全栈程序员-站长


相关推荐

  • javaweb项目连接MySQL数据库_php实现评论回复功能

    javaweb项目连接MySQL数据库_php实现评论回复功能Java+MySQL实现评论功能设计开发一、背景项目初始版本上线,有时间写点东西记录一下项目中的心得体会,通过这个项目学习了很多,要写下来的有很多,先从评论功能开始吧。由于项目需要增加评论功能,之前并无此方面的经验,因此项目开始的一段时间都在寻思着如何进行评论功能的设计。上网搜索一波…

    2022年10月1日
  • Origin绘图快速上手指南

    Origin绘图快速上手指南1、创建工程打开origin后,点击菜单栏“文件”,选择“项目另存为”,给项目命名,并存到某个工作路径。2、导入数据然后将excel中的数据(只要数据)选中后复制到Book1中,从第5行开始粘贴。可以在侧面打开“项目管理器”,给表格“Book1”重命名为“曲线数据”。还可以在表格的“长单位”处给每列数据加上标签。3、那么这时可以直接使用Origin的自动绘图功能了。选择A、B、C所有列,然后点击菜单栏的“绘图”,选择一个折线图,双击即可绘图。这样呢就是将两条曲线放到同一张图中了。如果想要自定

    2022年5月31日
  • 用python做一个贪吃蛇游戏_免费贪吃蛇试玩的游戏

    用python做一个贪吃蛇游戏_免费贪吃蛇试玩的游戏一、前言距上次更新博客,又过去很长时间了,感觉再不更新一下,自己写博客的习惯就要废了,哈哈。从去年九月份开学之后,疫情学期期末考试开学考、实验室项目软著申请和新项目设计、课程集训等事情较多,没有很多时间;然后这个学期我到大三下学期,实验室工作交接完就准备考研,之后也没有很多时间来写博客,所以赶紧来更新一下,和大家分享一些知识和心得,希望喜欢的小伙伴可以点赞、收藏和关注,哈哈。二、贪吃蛇大冒险小游戏一、游戏简介1.1游戏操作及游戏规则(1)游戏开始后,通过键盘上下左右键控制贪吃蛇移动寻找食物;(2

    2022年8月11日
  • plsql developer配置数据库连接_plsql使用教程

    plsql developer配置数据库连接_plsql使用教程一、概念PL/SQLDeveloper是一个集成开发环境,专门面向Oracle数据库存储程序单元的开发。如今,有越来越多的商业逻辑和应用逻辑转向了OracleServer,因此,PL/SQL编程也成了整个开发过程的一个重要组成部分。PL/SQLDeveloper侧重于易用性、代码品质和生产力,充分发挥Oracle应用程序开发过程中的主要优势。Oracle数据库并不提供图形界面的开发…

    2022年9月25日
  • navicat premium 15 mac 激活码【2021.8最新】

    (navicat premium 15 mac 激活码)这是一篇idea技术相关文章,由全栈君为大家提供,主要知识点是关于2021JetBrains全家桶永久激活码的内容IntelliJ2021最新激活注册码,破解教程可免费永久激活,亲测有效,下面是详细链接哦~https://javaforall.net/100143.htmlS32PGH0SQB-eyJsa…

    2022年3月25日

发表回复

您的邮箱地址不会被公开。 必填项已用 * 标注

关注全栈程序员社区公众号